import json
import os
import unittest
from unittest.mock import patch

from eyesonly.acl.providers.env_acl_provider import EnvACLProvider


class TestEnvACLProvider(unittest.TestCase):
    def setUp(self) -> None:
        root_dir_path = os.path.dirname(os.path.abspath(__file__))
        self.resources_path = os.path.join(root_dir_path, '_resources')
        acl_json_path = os.path.join(self.resources_path, 'eyesonly.json')
        self.acl_config: str
        with open(acl_json_path, 'rb') as acl_file:
            self.acl_config: str = json.load(acl_file)

    def test_load(self):
        expected_acl = {
            'secret1': {
                '/$HOME/path/to/secret11.py': {'func1b', 'func1a'},
                '/$HOME/path/to/secret12.py': {'func2b', 'func2a'}
            },
            'secret2': {
                '/root/path/to/secret2.py': {'func4', 'func3'}
            }
        }

        acl_json = json.dumps({
            "eyesonly": {
                "secrets": [
                    {
                        "secret": "secret1",
                        "files": [
                            {
                                "file_path": "/$HOME/path/to/secret11.py",
                                "functions": [
                                    "func1b",
                                    "func1a"
                                ]
                            },
                            {
                                "file_path": "/$HOME/path/to/secret12.py",
                                "functions": ["func2b", "func2a"]
                            }
                        ]
                    },
                    {
                        "secret": "secret2",
                        "files": [
                            {
                                "file_path": "/root/path/to/secret2.py",
                                "functions": ["func4", "func3"]
                            }
                        ]
                    }
                ]
            }
        })

        with patch.dict(os.environ, {'test_acl': acl_json}, clear=True):
            acl_provider = EnvACLProvider(env_variable='test_acl')
            acl = acl_provider.load()

        self.assertEqual(expected_acl, acl)



from typing import Union

from eyesonly.acl.acl_type import ACLType
from eyesonly.acl.providers.env_acl_provider import EnvACLProvider
from eyesonly.acl.providers.json_acl_provider import JSONACLProvider
from eyesonly.acl.providers.toml_acl_provider import TomlACLProvider


class ACL:
    def __init__(self, provider: Union[JSONACLProvider, TomlACLProvider, EnvACLProvider]):
        self.__provider = provider
        self.__acl: ACLType = provider.load()

    def allowed(self, secret: str, file_path: str, function: str):
        return function in self.__acl.get(secret, {}).get(file_path, set())



import os
from typing import BinaryIO, List

from eyesonly.acl.acl_type import ACLType
from eyesonly.acl.providers.base_acl_provider import BaseACLProvider


class BaseFileACLProvider(BaseACLProvider):
    def __init__(self, file_path: str):
        if not os.path.isfile(file_path):
            raise ValueError(f'File {file_path} is not a valid file path')

        self._config_file_path = file_path
        self._config_dir_path = os.path.dirname(os.path.abspath(file_path))

    def _load(self, acl_config_file: BinaryIO):
        raise NotImplementedError

    def _absolutize_file_path(self, file_path: str) -> str:
        return os.path.realpath(
            os.path.join(self._config_dir_path, file_path)
        )

    def load(self) -> ACLType:
        with open(self._config_file_path, 'rb') as acl_file:
            input_config = self._load(acl_file)
        return self._input_acl_to_acl(input_acl=input_config)



import json
import os
import time
import unittest

from eyesonly.acl.acl import ACL
from eyesonly.acl.providers.env_acl_provider import EnvACLProvider
from eyesonly.acl.providers.json_acl_provider import JSONACLProvider
from eyesonly.acl.providers.toml_acl_provider import TomlACLProvider
from eyesonly.exceptions import EyesOnlyException
from eyesonly.secret import Secret


class TestSecret(unittest.TestCase):
    def setUp(self) -> None:
        root_path = os.path.dirname(os.path.abspath(__file__))
        resources_path = os.path.join(root_path, '_resources')

        json_config_file_path = os.path.join(resources_path, 'eyesonly.json')
        toml_config_file_path = os.path.join(resources_path, 'eyesonly.toml')

        os.environ['test_acl'] = json.dumps({
            "eyesonly": {
                "secrets": [
                    {
                        "secret": "env_secret1",
                        "files": [
                            {
                                "file_path": os.path.join(root_path, 'test_secret.py'),
                                "functions": ["test_env_config_secret_allowed"]
                            }
                        ]
                    }
                ]
            }
        })

        self.json_acl = ACL(JSONACLProvider(file_path=json_config_file_path))
        self.env_acl = ACL(EnvACLProvider(env_variable='test_acl'))
        self.toml_acl = ACL(TomlACLProvider(file_path=toml_config_file_path))

    def test_missing_secret(self):
        secret = Secret(name='missing_secret', value='SECRET_API_KEY', acl=self.json_acl)
        with self.assertRaises(EyesOnlyException) as exc_context:
            str(secret)

        self.assertEqual('Secret missing_secret is not allowed to be seen here',
                         str(exc_context.exception))

    def test_json_config_secret_not_allowed(self):
        secret = Secret(name='secret_not_allowed_anywhere', value='SECRET_API_KEY', acl=self.json_acl)
        with self.assertRaises(EyesOnlyException) as exc_context:
            str(secret)

        self.assertEqual('Secret secret_not_allowed_anywhere is not allowed to be seen here',
                         str(exc_context.exception))

    def test_json_config_secret_not_allowed_exception_denied_policy(self):
        secret = Secret(name='secret_not_allowed_anywhere', value='SECRET_API_KEY', acl=self.json_acl,
                        denied_policy='exception')
        with self.assertRaises(EyesOnlyException) as exc_context:
            str(secret)

        self.assertEqual('Secret secret_not_allowed_anywhere is not allowed to be seen here',
                         str(exc_context.exception))

    def test_json_config_secret_not_allowed_censure_denied_policy(self):
        secret = Secret(name='secret_not_allowed_anywhere', value='SECRET_API_KEY', acl=self.json_acl,
                        denied_policy='censure')

        self.assertEqual('*****', str(secret))

    def test_json_config_secret_allowed(self):
        secret = Secret(name='secret_allowed', acl=self.json_acl, value='SECRET_API_KEY')
        value = str(secret)

        self.assertEqual('SECRET_API_KEY', value)

    def test_json_config_allowed_in_inner_function_with_allowed_caller_function(self):
        def inner_function():
            secret = Secret(name='secret_allowed', acl=self.json_acl, value='SECRET_API_KEY')

            return str(secret)

        self.assertEqual('SECRET_API_KEY', inner_function())

    def test_json_config_allowed_in_inner_function_with_not_allowed_caller_function(self):
        def inner_function_in_test():
            secret = Secret(name='secret_allowed', acl=self.json_acl, value='SECRET_API_KEY')

            return str(secret)

        self.assertEqual('SECRET_API_KEY', inner_function_in_test())

    def test_toml_config_secret_not_allowed(self):
        secret = Secret(name='secret_not_allowed_anywhere', value='SECRET_API_KEY', acl=self.toml_acl)
        with self.assertRaises(EyesOnlyException) as exc_context:
            str(secret)

        self.assertEqual('Secret secret_not_allowed_anywhere is not allowed to be seen here',
                         str(exc_context.exception))

    def test_toml_config_secret_allowed(self):
        secret = Secret(name='secret_allowed', acl=self.toml_acl, value='SECRET_API_KEY')
        value = str(secret)

        self.assertEqual('SECRET_API_KEY', value)

    def test_env_config_secret_not_allowed(self):
        secret = Secret(name='env_secret1', value='ENV_SECRET1', acl=self.env_acl)
        with self.assertRaises(EyesOnlyException) as exc_context:
            str(secret)

        self.assertEqual('Secret env_secret1 is not allowed to be seen here',
                         str(exc_context.exception))

    def test_env_config_secret_allowed(self):
        secret = Secret(name='env_secret1', acl=self.env_acl, value='ENV_SECRET1')
        value = str(secret)

        self.assertEqual('ENV_SECRET1', value)



from typing import Dict, Set, List, Union

# TODO: use TypedDict
InputACLType = Dict[str, Dict[str, Union[str, List[Dict[str, List[Dict[str, Union[str, List[str]]]]]]]]]
ACLType = Dict[str, Dict[str, Dict[str, Set[str]]]]



import unittest

from eyesonly.acl.providers.base_acl_provider import BaseACLProvider


class TestBaseACLProvider(unittest.TestCase):
    def test_load(self):
        acl_provider = BaseACLProvider()
        with self.assertRaises(NotImplementedError):
            acl_provider.load()



import os
import unittest

from eyesonly.acl.providers.base_file_acl_provider import BaseFileACLProvider


class TestBaseFileACLProvider(unittest.TestCase):
    def setUp(self) -> None:
        root_dir_path = os.path.dirname(os.path.abspath(__file__))
        self.resources_path = os.path.join(root_dir_path, '_resources')

    def test_load(self):
        acl_provider = BaseFileACLProvider(file_path=os.path.join(self.resources_path, 'eyesonly.toml'))
        with self.assertRaises(NotImplementedError):
            acl_provider.load()



import json
from typing import BinaryIO

from eyesonly.acl.acl_type import ACLType
from eyesonly.acl.providers.base_file_acl_provider import BaseFileACLProvider


class JSONACLProvider(BaseFileACLProvider):
    def __init__(self, file_path: str = 'eyesonly.json'):
        super().__init__(file_path=file_path)

    def _load(self, acl_config_file: BinaryIO) -> ACLType:
        return json.load(acl_config_file)



import os
from setuptools import setup, find_packages

root_dir_path = os.path.dirname(os.path.abspath(__file__))

long_description = open(os.path.join(root_dir_path, 'README.md')).read()

setup(
    name='eyesonly',
    version='0.0.2',
    author='Diego J. Romero López',
    author_email='diegojromerolopez@gmail.com',
    description='A package to avoid having leaks of secrets',
    long_description=long_description,
    long_description_content_type='text/markdown',
    classifiers=[
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Topic :: Software Development :: Libraries',
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License'
    ],
    install_requires=[
        'tomli >= 1.1.0 ; python_version < "3.11"'
    ],
    license='MIT',
    keywords=('secrets', 'leaks', 'isolation'),
    url='https://github.com/diegojromerolopez/eyesonly',
    packages=find_packages(),
    data_files=[],
    include_package_data=True,
    scripts=[]
)



from typing import List, Dict

from eyesonly.acl.acl_type import ACLType, InputACLType


class BaseACLProvider:

    def _absolutize_file_path(self, file_path: str):
        return file_path

    def _input_acl_to_acl(self, input_acl: InputACLType) -> ACLType:
        acl = {}
        for secret_attrs in input_acl.get('eyesonly', {}).get('secrets', {}):
            secret: str = secret_attrs['secret']
            acl[secret] = {}
            for file_attrs in secret_attrs['files']:
                file_path: str = self._absolutize_file_path(file_attrs['file_path'])
                functions: List[str] = file_attrs['functions']
                acl[secret][file_path] = set(functions)
        return acl

    def load(self) -> ACLType:
        raise NotImplementedError



import os
import unittest

from eyesonly.acl.providers.json_acl_provider import JSONACLProvider


class TestJSONACLProvider(unittest.TestCase):
    def setUp(self) -> None:
        root_dir_path = os.path.dirname(os.path.abspath(__file__))
        self.resources_path = os.path.join(root_dir_path, '_resources')

    def test_acl_file_path_does_not_exist(self):
        with self.assertRaises(ValueError) as exc_context:
            JSONACLProvider(file_path='this/file/does/not/exist.toml')

        self.assertEqual('File this/file/does/not/exist.toml is not a valid file path',
                         str(exc_context.exception))

    def test_load(self):
        expected_acl = {
            'secret1': {
                os.path.realpath(os.path.join(self.resources_path, '../../path/to/secret11.py')): {'func1b', 'func1a'},
                os.path.realpath(os.path.join(self.resources_path, '../../path/to/secret12.py')): {'func2b', 'func2a'}
            },
            'secret2': {
                '/root/path/to/secret2.py': {'func4', 'func3'}
            }
        }

        acl_provider = JSONACLProvider(file_path=os.path.join(self.resources_path, 'eyesonly.json'))
        acl = acl_provider.load()

        self.assertEqual(expected_acl, acl)



import json
import os
from typing import BinaryIO, Dict, List

from eyesonly.acl.acl_type import ACLType
from eyesonly.acl.providers.base_acl_provider import BaseACLProvider


class EnvACLProvider(BaseACLProvider):
    def __init__(self, env_variable: str):
        self.__env_variable = env_variable
        if self.__env_variable not in os.environ:
            raise ValueError(f'Environment variable {self.__env_variable} not found')

    def load(self) -> ACLType:
        input_acl = json.loads(os.environ[self.__env_variable])
        return self._input_acl_to_acl(input_acl=input_acl)
